@@ -7,7 +7,7 @@ with qw/Verby::Action/;
 
 use File::Path qw/mkpath/;
 
-our $VERSION = "0.03";
+our $VERSION = "0.04";
 
 sub do {
 	my $self = shift;
@@ -16,13 +16,13 @@ sub do {
 	my $path = $c->path;
 
 	if ( !defined($path) || !length($path) ){
-		$c->logger->logdie("invalid path");
+		$c->logger->log_and_die(level => "error", message => "invalid path");
 	}
 
 	$c->logger->info("creating path '$path'");
 
 	mkpath($path)
-		or $c->logger->logdie("couldn't mkpath('$path'): $!");
+		or $c->logger->log_and_die(level => "error", message => "couldn't mkpath('$path'): $!");
 
 	$self->confirm($c);
 }
@@ -87,7 +87,7 @@ Yuval Kogman, E<lt>nothingmuch@woobling.orgE<gt>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright 2005, 2006 by Infinity Interactive, Inc.
+Copyright 2005-2008 by Infinity Interactive, Inc.
 
 L<http://www.iinteractive.com>
 
